==> zio-aws-ec2_2.12-5.20.32.2-sources.jar: zio/aws/ec2/model/EnableAwsNetworkPerformanceMetricSubscriptionRequest.scala <==
package zio.aws.ec2.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class EnableAwsNetworkPerformanceMetricSubscriptionRequest(
    source: Optional[String] = Optional.Absent,
    destination: Optional[String] = Optional.Absent,
    metric: Optional[zio.aws.ec2.model.MetricType] = Optional.Absent,
    statistic: Optional[zio.aws.ec2.model.StatisticType] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.EnableAwsNetworkPerformanceMetricSubscriptionRequest = {
    import EnableAwsNetworkPerformanceMetricSubscriptionRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.EnableAwsNetworkPerformanceMetricSubscriptionRequest
      .builder()
      .optionallyWith(source.map(value => value: java.lang.String))(_.source)
      .optionallyWith(destination.map(value => value: java.lang.String))(
        _.destination
      )
      .optionallyWith(metric.map(value => value.unwrap))(_.metric)
      .optionallyWith(statistic.map(value => value.unwrap))(_.statistic)
      .build()
  }
  def asReadOnly
      : zio.aws.ec2.model.EnableAwsNetworkPerformanceMetricSubscriptionRequest.ReadOnly =
    zio.aws.ec2.model.EnableAwsNetworkPerformanceMetricSubscriptionRequest
      .wrap(buildAwsValue())
}
object EnableAwsNetworkPerformanceMetricSubscriptionRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.EnableAwsNetworkPerformanceMetricSubscriptionRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.ec2.model.EnableAwsNetworkPerformanceMetricSubscriptionRequest =
      zio.aws.ec2.model.EnableAwsNetworkPerformanceMetricSubscriptionRequest(
        source.map(value => value),
        destination.map(value => value),
        metric.map(value => value),
        statistic.map(value => value)
      )
    def source: Optional[String]
    def destination: Optional[String]
    def metric: Optional[zio.aws.ec2.model.MetricType]
    def statistic: Optional[zio.aws.ec2.model.StatisticType]
    def getSource: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("source", source)
    def getDestination: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("destination", destination)
    def getMetric: ZIO[Any, AwsError, zio.aws.ec2.model.MetricType] =
      AwsError.unwrapOptionField("metric", metric)
    def getStatistic: ZIO[Any, AwsError, zio.aws.ec2.model.StatisticType] =
      AwsError.unwrapOptionField("statistic", statistic)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.EnableAwsNetworkPerformanceMetricSubscriptionRequest
  ) extends zio.aws.ec2.model.EnableAwsNetworkPerformanceMetricSubscriptionRequest.ReadOnly {
    override val source: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.source())
      .map(value => value: String)
    override val destination: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.destination())
      .map(value => value: String)
    override val metric: Optional[zio.aws.ec2.model.MetricType] =
      zio.aws.core.internal
        .optionalFromNullable(impl.metric())
        .map(value => zio.aws.ec2.model.MetricType.wrap(value))
    override val statistic: Optional[zio.aws.ec2.model.StatisticType] =
      zio.aws.core.internal
        .optionalFromNullable(impl.statistic())
        .map(value => zio.aws.ec2.model.StatisticType.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.EnableAwsNetworkPerformanceMetricSubscriptionRequest
  ): zio.aws.ec2.model.EnableAwsNetworkPerformanceMetricSubscriptionRequest.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-ec2_2.12-7.21.15.7-sources.jar: zio/aws/ec2/model/EnableAwsNetworkPerformanceMetricSubscriptionRequest.scala <==
package zio.aws.ec2.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class EnableAwsNetworkPerformanceMetricSubscriptionRequest(
    source: Optional[String] = Optional.Absent,
    destination: Optional[String] = Optional.Absent,
    metric: Optional[zio.aws.ec2.model.MetricType] = Optional.Absent,
    statistic: Optional[zio.aws.ec2.model.StatisticType] = Optional.Absent,
    dryRun: Optional[Boolean] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.EnableAwsNetworkPerformanceMetricSubscriptionRequest = {
    import EnableAwsNetworkPerformanceMetricSubscriptionRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.EnableAwsNetworkPerformanceMetricSubscriptionRequest
      .builder()
      .optionallyWith(source.map(value => value: java.lang.String))(_.source)
      .optionallyWith(destination.map(value => value: java.lang.String))(
        _.destination
      )
      .optionallyWith(metric.map(value => value.unwrap))(_.metric)
      .optionallyWith(statistic.map(value => value.unwrap))(_.statistic)
      .optionallyWith(dryRun.map(value => value: java.lang.Boolean))(_.dryRun)
      .build()
  }
  def asReadOnly
      : zio.aws.ec2.model.EnableAwsNetworkPerformanceMetricSubscriptionRequest.ReadOnly =
    zio.aws.ec2.model.EnableAwsNetworkPerformanceMetricSubscriptionRequest
      .wrap(buildAwsValue())
}
object EnableAwsNetworkPerformanceMetricSubscriptionRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.EnableAwsNetworkPerformanceMetricSubscriptionRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.ec2.model.EnableAwsNetworkPerformanceMetricSubscriptionRequest =
      zio.aws.ec2.model.EnableAwsNetworkPerformanceMetricSubscriptionRequest(
        source.map(value => value),
        destination.map(value => value),
        metric.map(value => value),
        statistic.map(value => value),
        dryRun.map(value => value)
      )
    def source: Optional[String]
    def destination: Optional[String]
    def metric: Optional[zio.aws.ec2.model.MetricType]
    def statistic: Optional[zio.aws.ec2.model.StatisticType]
    def dryRun: Optional[Boolean]
    def getSource: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("source", source)
    def getDestination: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("destination", destination)
    def getMetric: ZIO[Any, AwsError, zio.aws.ec2.model.MetricType] =
      AwsError.unwrapOptionField("metric", metric)
    def getStatistic: ZIO[Any, AwsError, zio.aws.ec2.model.StatisticType] =
      AwsError.unwrapOptionField("statistic", statistic)
    def getDryRun: ZIO[Any, AwsError, Boolean] =
      AwsError.unwrapOptionField("dryRun", dryRun)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.EnableAwsNetworkPerformanceMetricSubscriptionRequest
  ) extends zio.aws.ec2.model.EnableAwsNetworkPerformanceMetricSubscriptionRequest.ReadOnly {
    override val source: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.source())
      .map(value => value: String)
    override val destination: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.destination())
      .map(value => value: String)
    override val metric: Optional[zio.aws.ec2.model.MetricType] =
      zio.aws.core.internal
        .optionalFromNullable(impl.metric())
        .map(value => zio.aws.ec2.model.MetricType.wrap(value))
    override val statistic: Optional[zio.aws.ec2.model.StatisticType] =
      zio.aws.core.internal
        .optionalFromNullable(impl.statistic())
        .map(value => zio.aws.ec2.model.StatisticType.wrap(value))
    override val dryRun: Optional[Boolean] = zio.aws.core.internal
      .optionalFromNullable(impl.dryRun())
      .map(value => value: Boolean)
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.EnableAwsNetworkPerformanceMetricSubscriptionRequest
  ): zio.aws.ec2.model.EnableAwsNetworkPerformanceMetricSubscriptionRequest.ReadOnly =
    new Wrapper(impl)
}
